@@ -4,8 +4,8 @@ $self = {
           'deps' => [
                       'Glib'
                     ],
-          'inc' => '-I/usr/include/dbus-1.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/dbus-1.0 -I/usr/lib/dbus-1.0/include  -I. -Ibuild -I/usr/src/ports/xfconf/xfconf-4.10.0-3.i686/build/xfconf-perl/.. -I/usr/src/ports/xfconf/xfconf-4.10.0-3.i686/src/xfconf-4.10.0',
-          'libs' => '-L/usr/src/ports/xfconf/xfconf-4.10.0-3.i686/build/xfconf-perl/../common/.libs -L/usr/src/ports/xfconf/xfconf-4.10.0-3.i686/build/xfconf-perl/../xfconf/.libs -lxfconf-gvaluefuncs -lxfconf-0 -ldbus-glib-1 -lgobject-2.0 -lffi -lglib-2.0 -lintl -lpcre -lintl -liconv -lpcre -ldbus-1 ',
+          'inc' => '-I/usr/include/dbus-1.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/dbus-1.0 -I/usr/lib/dbus-1.0/include -I. -Ibuild -I/usr/src/ports/xfconf/xfconf-4.12.0-2.i686/build/xfconf-perl/.. -I/usr/src/ports/xfconf/xfconf-4.12.0-2.i686/src/xfconf-4.12.0',
+          'libs' => '-L/usr/src/ports/xfconf/xfconf-4.12.0-2.i686/build/xfconf-perl/../common/.libs -L/usr/src/ports/xfconf/xfconf-4.12.0-2.i686/build/xfconf-perl/../xfconf/.libs -lxfconf-gvaluefuncs -lxfconf-0 -ldbus-glib-1 -lgobject-2.0 -lglib-2.0 -lintl -ldbus-1',
           'typemaps' => [
                           'xfconfperl.typemap'
                         ]
